parse_triples

Function parse_triples 

pub fn parse_triples<R: BufRead, F: FnMut(Triple) -> Result<()>>(
    reader: R,
    format: InputFormat,
    on_triple: F,
) -> Result<ParseOutcome>
Stream-parse reader according to format. For each triple (after dropping any graph context for quad formats), invoke on_triple. Triples involving a blank node are skipped and increment the skipped counter.

Returns a ParseOutcome containing totals and any prefix declarations seen in the source.