pub fn quad_to_triple(q: &Quad) -> TripleExpand description
Convenience: produces a triple from a quad by dropping the graph component.
pub fn quad_to_triple(q: &Quad) -> TripleConvenience: produces a triple from a quad by dropping the graph component.